# GAN ZOO

[![Documentation](https://img.shields.io/badge/documentation-master-green.svg)](https://innerlee.github.io/ganzoo/)
[![PyPI Version](https://img.shields.io/pypi/v/ganzoo.svg)](https://pypi.python.org/pypi/ganzoo)
[![Python Version](https://img.shields.io/pypi/pyversions/ganzoo.svg)]()
[![Build Status](https://travis-ci.org/innerlee/ganzoo.svg?branch=master)](https://travis-ci.org/innerlee/ganzoo)
[![Coverage Status](https://codecov.io/gh/innerlee/ganzoo/branch/master/graph/badge.svg)](https://codecov.io/gh/innerlee/ganzoo)


`ganzoo` implements all the GANs. Currently, it includes

- GAN
- DCGAN
- WGAN
- WGAN-GP
- CGAN

Try and start with

```shell
pip install ganzoo
```
